###########################################################################
#
# WordPlug.pm -- plugin for importing Microsoft Word documents
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 1999 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

# 12/05/02 Added usage datastructure - John Thompson

package WordPlug;

use ConvertToPlug;

sub BEGIN {
    @ISA = ('ConvertToPlug');
}

my $arguments = [ { 'name' => "process_exp",
						  'desc' => "A perl regular expression to match against filenames. Matching filenames will be processed by this plugin. Each plugin has its own default process_exp. e.g HTMLPlug defaults to '(?i)\.html?\$' i.e. all documents ending in .htm or .html (case-insensitive).",
						  'type' => "string",
						  'deft' => q^(?i)\.doc$^,
						  'reqd' => "no" } ];

my $options = { 'name'     => "WordPlug",
	             'desc'     => "",
					 'inherits' => "yes",
					 'args'     => $arguments };

sub new {
    my $class = shift (@_);

    my $self = new ConvertToPlug ($class, @_);

	 # 14-05-02 To allow for proper inheritance of arguments - John Thompson
	 my $option_list = $self->{'option_list'};
	 push( @{$option_list}, $options );

    # wvWare will always produce html files encoded as utf-8
    if ($self->{'input_encoding'} eq "auto") {
	$self->{'input_encoding'} = "utf8";
	$self->{'extract_language'} = 1;
    }

    return bless $self, $class;
}

sub get_default_process_exp {
    my $self = shift (@_);

    return q^(?i)\.(doc|dot)$^;
}

# do plugin specific processing of doc_obj for HTML type
sub process {
    my $self = shift (@_);

    my $outhandle = $self->{'outhandle'};    
    print $outhandle "WordPlug: passing $_[3] on to $self->{'converted_to'}Plug\n" 
	if $self->{'verbosity'} > 1;
    
    return ConvertToPlug::process_type($self,"doc",@_);
}

1;
